@@ -22,10 +22,6 @@ NULL
 #' @importFrom stats anova as.formula confint cor.test fisher.test ks.test mad median na.omit p.adjust pairwise.t.test pnorm power.prop.test power.t.test qnorm quantile rpois sd wilcox.test t.test var.test
 NULL
 
-#' @importFrom magrittr `%<>%`
-#' @export
-magrittr::`%<>%`
-
 #' @import ggplot2
 NULL
 
